@@ -210,6 +210,24 @@ class ApplicationsAsyncClient:
     ) -> application.Application:
         r"""Gets information about an application.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_get_application():
+                # Create a client
+                client = appengine_admin_v1.ApplicationsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.GetApplicationRequest(
+                )
+
+                # Make the request
+                response = client.get_application(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetApplicationRequest, dict]):
                 The request object. Request message for
@@ -270,6 +288,29 @@ class ApplicationsAsyncClient:
         `Managing Projects, Applications, and
         Billing <https://cloud.google.com/appengine/docs/standard/python/console/>`__.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_create_application():
+                # Create a client
+                client = appengine_admin_v1.ApplicationsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.CreateApplicationRequest(
+                )
+
+                # Make the request
+                operation = client.create_application(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.CreateApplicationRequest, dict]):
                 The request object. Request message for
@@ -329,6 +370,29 @@ class ApplicationsAsyncClient:
         -  ``default_cookie_expiration`` - Cookie expiration policy for
            the application.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_update_application():
+                # Create a client
+                client = appengine_admin_v1.ApplicationsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.UpdateApplicationRequest(
+                )
+
+                # Make the request
+                operation = client.update_application(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateApplicationRequest, dict]):
                 The request object. Request message for
@@ -398,6 +462,29 @@ class ApplicationsAsyncClient:
         . If the deletion was recent, the numeric ID can be found in the
         Cloud Console Activity Log.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_repair_application():
+                # Create a client
+                client = appengine_admin_v1.ApplicationsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.RepairApplicationRequest(
+                )
+
+                # Make the request
+                operation = client.repair_application(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.RepairApplicationRequest, dict]):
                 The request object. Request message for
