@@ -219,6 +219,26 @@ class AuthorizedCertificatesAsyncClient:
         r"""Lists all SSL certificates the user is authorized to
         administer.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_list_authorized_certificates():
+                # Create a client
+                client = appengine_admin_v1.AuthorizedCertificatesClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.ListAuthorizedCertificatesRequest(
+                )
+
+                # Make the request
+                page_result = client.list_authorized_certificates(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListAuthorizedCertificatesRequest, dict]):
                 The request object. Request message for
@@ -277,6 +297,24 @@ class AuthorizedCertificatesAsyncClient:
     ) -> certificate.AuthorizedCertificate:
         r"""Gets the specified SSL certificate.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_get_authorized_certificate():
+                # Create a client
+                client = appengine_admin_v1.AuthorizedCertificatesClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.GetAuthorizedCertificateRequest(
+                )
+
+                # Make the request
+                response = client.get_authorized_certificate(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetAuthorizedCertificateRequest, dict]):
                 The request object. Request message for
@@ -329,6 +367,24 @@ class AuthorizedCertificatesAsyncClient:
     ) -> certificate.AuthorizedCertificate:
         r"""Uploads the specified SSL certificate.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_create_authorized_certificate():
+                # Create a client
+                client = appengine_admin_v1.AuthorizedCertificatesClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.CreateAuthorizedCertificateRequest(
+                )
+
+                # Make the request
+                response = client.create_authorized_certificate(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.CreateAuthorizedCertificateRequest, dict]):
                 The request object. Request message for
@@ -386,6 +442,25 @@ class AuthorizedCertificatesAsyncClient:
         certificate. The certificate ``display_name`` may also be
         updated.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_update_authorized_certificate():
+                # Create a client
+                client = appengine_admin_v1.AuthorizedCertificatesClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.UpdateAuthorizedCertificateRequest(
+                )
+
+                # Make the request
+                response = client.update_authorized_certificate(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateAuthorizedCertificateRequest, dict]):
                 The request object. Request message for
@@ -438,6 +513,21 @@ class AuthorizedCertificatesAsyncClient:
     ) -> None:
         r"""Deletes the specified SSL certificate.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_delete_authorized_certificate():
+                # Create a client
+                client = appengine_admin_v1.AuthorizedCertificatesClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.DeleteAuthorizedCertificateRequest(
+                )
+
+                # Make the request
+                client.delete_authorized_certificate(request=request)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteAuthorizedCertificateRequest, dict]):
                 The request object. Request message for
