@@ -215,6 +215,25 @@ class DomainMappingsAsyncClient:
     ) -> pagers.ListDomainMappingsAsyncPager:
         r"""Lists the domain mappings on an application.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_list_domain_mappings():
+                # Create a client
+                client = appengine_admin_v1.DomainMappingsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.ListDomainMappingsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_domain_mappings(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListDomainMappingsRequest, dict]):
                 The request object. Request message for
@@ -272,6 +291,24 @@ class DomainMappingsAsyncClient:
     ) -> domain_mapping.DomainMapping:
         r"""Gets the specified domain mapping.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_get_domain_mapping():
+                # Create a client
+                client = appengine_admin_v1.DomainMappingsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.GetDomainMappingRequest(
+                )
+
+                # Make the request
+                response = client.get_domain_mapping(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetDomainMappingRequest, dict]):
                 The request object. Request message for
@@ -324,6 +361,29 @@ class DomainMappingsAsyncClient:
         list of available authorized domains, see
         ```AuthorizedDomains.ListAuthorizedDomains`` <>`__.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_create_domain_mapping():
+                # Create a client
+                client = appengine_admin_v1.DomainMappingsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.CreateDomainMappingRequest(
+                )
+
+                # Make the request
+                operation = client.create_domain_mapping(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.CreateDomainMappingRequest, dict]):
                 The request object. Request message for
@@ -388,6 +448,29 @@ class DomainMappingsAsyncClient:
         administer the associated domain in order to update a
         ``DomainMapping`` resource.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_update_domain_mapping():
+                # Create a client
+                client = appengine_admin_v1.DomainMappingsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.UpdateDomainMappingRequest(
+                )
+
+                # Make the request
+                operation = client.update_domain_mapping(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateDomainMappingRequest, dict]):
                 The request object. Request message for
@@ -450,6 +533,29 @@ class DomainMappingsAsyncClient:
         to administer the associated domain in order to delete a
         ``DomainMapping`` resource.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_delete_domain_mapping():
+                # Create a client
+                client = appengine_admin_v1.DomainMappingsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.DeleteDomainMappingRequest(
+                )
+
+                # Make the request
+                operation = client.delete_domain_mapping(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteDomainMappingRequest, dict]):
                 The request object. Request message for
