@@ -214,6 +214,25 @@ class FirewallAsyncClient:
     ) -> pagers.ListIngressRulesAsyncPager:
         r"""Lists the firewall rules of an application.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_list_ingress_rules():
+                # Create a client
+                client = appengine_admin_v1.FirewallClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.ListIngressRulesRequest(
+                )
+
+                # Make the request
+                page_result = client.list_ingress_rules(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListIngressRulesRequest, dict]):
                 The request object. Request message for
@@ -277,6 +296,25 @@ class FirewallAsyncClient:
         IP range, then an "allow all" rule is explicitly added to the
         end of the list.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_batch_update_ingress_rules():
+                # Create a client
+                client = appengine_admin_v1.FirewallClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.BatchUpdateIngressRulesRequest(
+                )
+
+                # Make the request
+                response = client.batch_update_ingress_rules(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.BatchUpdateIngressRulesRequest, dict]):
                 The request object. Request message for
@@ -324,6 +362,24 @@ class FirewallAsyncClient:
     ) -> firewall.FirewallRule:
         r"""Creates a firewall rule for the application.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_create_ingress_rule():
+                # Create a client
+                client = appengine_admin_v1.FirewallClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.CreateIngressRuleRequest(
+                )
+
+                # Make the request
+                response = client.create_ingress_rule(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.CreateIngressRuleRequest, dict]):
                 The request object. Request message for
@@ -375,6 +431,24 @@ class FirewallAsyncClient:
     ) -> firewall.FirewallRule:
         r"""Gets the specified firewall rule.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_get_ingress_rule():
+                # Create a client
+                client = appengine_admin_v1.FirewallClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.GetIngressRuleRequest(
+                )
+
+                # Make the request
+                response = client.get_ingress_rule(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetIngressRuleRequest, dict]):
                 The request object. Request message for
@@ -426,6 +500,24 @@ class FirewallAsyncClient:
     ) -> firewall.FirewallRule:
         r"""Updates the specified firewall rule.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_update_ingress_rule():
+                # Create a client
+                client = appengine_admin_v1.FirewallClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.UpdateIngressRuleRequest(
+                )
+
+                # Make the request
+                response = client.update_ingress_rule(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateIngressRuleRequest, dict]):
                 The request object. Request message for
@@ -477,6 +569,21 @@ class FirewallAsyncClient:
     ) -> None:
         r"""Deletes the specified firewall rule.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_delete_ingress_rule():
+                # Create a client
+                client = appengine_admin_v1.FirewallClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.DeleteIngressRuleRequest(
+                )
+
+                # Make the request
+                client.delete_ingress_rule(request=request)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteIngressRuleRequest, dict]):
                 The request object. Request message for
