@@ -208,6 +208,25 @@ class ServicesAsyncClient:
     ) -> pagers.ListServicesAsyncPager:
         r"""Lists all the services in the application.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_list_services():
+                # Create a client
+                client = appengine_admin_v1.ServicesClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.ListServicesRequest(
+                )
+
+                # Make the request
+                page_result = client.list_services(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListServicesRequest, dict]):
                 The request object. Request message for
@@ -266,6 +285,25 @@ class ServicesAsyncClient:
         r"""Gets the current configuration of the specified
         service.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_get_service():
+                # Create a client
+                client = appengine_admin_v1.ServicesClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.GetServiceRequest(
+                )
+
+                # Make the request
+                response = client.get_service(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetServiceRequest, dict]):
                 The request object. Request message for
@@ -325,6 +363,28 @@ class ServicesAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the configuration of the specified service.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_update_service():
+                # Create a client
+                client = appengine_admin_v1.ServicesClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.UpdateServiceRequest(
+                )
+
+                # Make the request
+                operation = client.update_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateServiceRequest, dict]):
                 The request object. Request message for
@@ -392,6 +452,29 @@ class ServicesAsyncClient:
         r"""Deletes the specified service and all enclosed
         versions.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_delete_service():
+                # Create a client
+                client = appengine_admin_v1.ServicesClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.DeleteServiceRequest(
+                )
+
+                # Make the request
+                operation = client.delete_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteServiceRequest, dict]):
                 The request object. Request message for
