@@ -211,6 +211,25 @@ class VersionsAsyncClient:
     ) -> pagers.ListVersionsAsyncPager:
         r"""Lists the versions of a service.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_list_versions():
+                # Create a client
+                client = appengine_admin_v1.VersionsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.ListVersionsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_versions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.ListVersionsRequest, dict]):
                 The request object. Request message for
@@ -270,6 +289,25 @@ class VersionsAsyncClient:
         ``BASIC_VIEW`` will be returned. Specify the ``FULL_VIEW``
         parameter to get the full resource.
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_get_version():
+                # Create a client
+                client = appengine_admin_v1.VersionsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.GetVersionRequest(
+                )
+
+                # Make the request
+                response = client.get_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.GetVersionRequest, dict]):
                 The request object. Request message for
@@ -320,6 +358,28 @@ class VersionsAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deploys code and resource files to a new version.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_create_version():
+                # Create a client
+                client = appengine_admin_v1.VersionsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.CreateVersionRequest(
+                )
+
+                # Make the request
+                operation = client.create_version(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.CreateVersionRequest, dict]):
                 The request object. Request message for
@@ -414,6 +474,29 @@ class VersionsAsyncClient:
 
         -  ```manual_scaling.instances`` <https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#manualscaling>`__
 
+
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_update_version():
+                # Create a client
+                client = appengine_admin_v1.VersionsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.UpdateVersionRequest(
+                )
+
+                # Make the request
+                operation = client.update_version(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.UpdateVersionRequest, dict]):
                 The request object. Request message for
@@ -473,6 +556,28 @@ class VersionsAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes an existing Version resource.
 
+        .. code-block::
+
+            from google.cloud import appengine_admin_v1
+
+            def sample_delete_version():
+                # Create a client
+                client = appengine_admin_v1.VersionsClient()
+
+                # Initialize request argument(s)
+                request = appengine_admin_v1.DeleteVersionRequest(
+                )
+
+                # Make the request
+                operation = client.delete_version(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.appengine_admin_v1.types.DeleteVersionRequest, dict]):
                 The request object. Request message for
