@@ -251,8 +251,7 @@ class Version(proto.Message):
             Only returned in ``GET`` requests if ``view=FULL`` is set.
         version_url (str):
             Serving URL for this version. Example:
-            "https://myversion-dot-myservice-dot-
-            myapp.appspot.com"
+            "https://myversion-dot-myservice-dot-myapp.appspot.com"
             @OutputOnly
         endpoints_api_service (google.cloud.appengine_admin_v1.types.EndpointsApiService):
             Cloud Endpoints configuration.
@@ -701,8 +700,8 @@ class VpcAccessConnector(proto.Message):
     Attributes:
         name (str):
             Full Serverless VPC Access Connector name
-            e.g. /projects/my-project/locations/us-
-            central1/connectors/c1.
+            e.g.
+            /projects/my-project/locations/us-central1/connectors/c1.
     """
 
     name = proto.Field(proto.STRING, number=1,)
